@@ -402,15 +402,21 @@ class offset(OpenSCADObject):
         should be chamfered (cut off with a straight line) or not (extended to 
         their intersection).
     :type chamfer: bool
+
+    :param segments: Resolution of any radial curves
+    :type segments: int
     """
 
-    def __init__(self, r: float = None, delta: float = None, chamfer: bool = False) -> None:
+    def __init__(self, r: float = None, delta: float = None, chamfer: bool = False,
+                segments: int=None) -> None:
         if r:
             kwargs = {'r': r}
         elif delta:
             kwargs = {'delta': delta, 'chamfer': chamfer}
         else:
             raise ValueError("offset(): Must supply r or delta")
+        if segments:
+            kwargs['segments'] = segments
         super().__init__('offset', kwargs)
 
 
@@ -514,11 +520,11 @@ class rotate_extrude(OpenSCADObject):
 
 
 class dxf_linear_extrude(OpenSCADObject):
-    def __init__(self, file: str, layer: float = None, height: float = None,
+    def __init__(self, file: PathStr, layer: float = None, height: float = None,
                  center: bool = None, convexity: int = None, twist: float = None,
                  slices: int = None) -> None:
         super().__init__('dxf_linear_extrude',
-                         {'file': file, 'layer': layer,
+                         {'file': Path(file).as_posix(), 'layer': layer,
                           'height': height, 'center': center,
                           'convexity': convexity, 'twist': twist,
                           'slices': slices})
@@ -544,7 +550,7 @@ class surface(OpenSCADObject):
     Surface reads information from text or image files.
 
     :param file: The path to the file containing the heightmap data.
-    :type file: string
+    :type file: PathStr
 
     :param center: This determines the positioning of the generated object. If 
     True, object is centered in X- and Y-axis. Otherwise, the object is placed 
@@ -660,9 +666,9 @@ class children(OpenSCADObject):
 
 
 class import_stl(OpenSCADObject):
-    def __init__(self, file: str, origin: P2 = (0, 0), convexity: int = None, layer: int = None) -> None:
+    def __init__(self, file: PathStr, origin: P2 = (0, 0), convexity: int = None, layer: int = None) -> None:
         super().__init__('import',
-                         {'file': file, 'origin': origin,
+                         {'file': Path(file).as_posix(), 'origin': origin,
                           'convexity': convexity, 'layer': layer})
 
 
@@ -679,7 +685,7 @@ class import_(OpenSCADObject):
     supports import of DXF and STL (both ASCII and Binary) files.
 
     :param file: path to the STL or DXF file.
-    :type file: string
+    :type file: PathStr
 
     :param convexity: The convexity parameter specifies the maximum number of 
     front sides (back sides) a ray intersecting the object might penetrate. This 
@@ -688,9 +694,9 @@ class import_(OpenSCADObject):
     :type convexity: int
     """
 
-    def __init__(self, file: str, origin: P2 = (0, 0), convexity: int = None, layer: int = None) -> None:
+    def __init__(self, file: PathStr, origin: P2 = (0, 0), convexity: int = None, layer: int = None) -> None:
         super().__init__('import',
-                         {'file': file, 'origin': origin,
+                         {'file': Path(file).as_posix(), 'origin': origin,
                           'convexity': convexity, 'layer': layer})
 
 
@@ -780,8 +786,7 @@ def import_scad(scad_filepath: PathStr) -> Optional[SimpleNamespace]:
 
 
 # use() & include() mimic OpenSCAD's use/include mechanics.
-# -- use() makes methods in scad_file_path.scad available to
-#   be called.
+# -- use() makes methods in scad_file_path.scad available to be called.
 # --include() makes those methods available AND executes all code in
 #   scad_file_path.scad, which may have side effects.
 #   Unless you have a specific need, call use().
@@ -827,5 +832,5 @@ def use(scad_file_path: PathStr, use_not_include: bool = True, dest_namespace_di
     return True
 
 
-def include(scad_file_path: str) -> bool:
+def include(scad_file_path: PathStr) -> bool:
     return use(scad_file_path, use_not_include=False)
